%define name silc-client
%define version 1.0.1
%define release 2mdk

%define major 1
%define client client
%define libname %mklibname %{name} %{major}
%define libclient %mklibname %{client} %{major}

Summary:	Client for the secure Internet Live Conferencing (SILC) protocol
Name:		%{name}
Version:	%{version}
Release:	%{release}
Source:		http://www.silcnet.org/download/client/sources/%{name}-%{version}.tar.bz2
Source1:	icons-%{name}.tar.bz2
License:	GPL
Group:		Networking/Chat
URL:		http://www.silcnet.org/
Requires:	ncurses >= 5.2
Requires:	%libname = %version-%release
Requires:	%libclient = %version-%release
BuildRequires:	ncurses-devel >= 5.2, perl-devel, glib-devel >= 1.2
BuildRoot:	%{_tmppath}/%{name}-buildroot

%description
SILC (Secure Internet Live Conferencing) is a protocol which provides
secure conferencing services on the Internet over insecure channel.
SILC is IRC-like software although internally they are very different.
The biggest similarity between SILC and IRC is that they both provide
conferencing services and that SILC has almost the same commands as IRC.
Other than that they are nothing alike.  Major differences are that SILC
is secure what IRC is not in any way.  The network model is also entirely
different compared to IRC.

%package -n %{libclient}
Summary: Libraries need by silc-client
Group: System/Libraries
Provides: %libclient = %version-%release

%description -n %{libclient}
Libraries need by silc-client

%package -n %{libname}
Summary: Generic libraries need by silc programs
Group: System/Libraries
Provides: %libname = %version-%release
Requires: %{libname} = %version-%release

%description -n %{libname}
Generic libraries need by silc programs

%package -n %{libclient}-devel
Summary: Development libraries from silc-client
Group: Development/Other
Provides: %libclient-devel = %version
Requires: %{libclient} = %version-%release
Requires: %{libname}-devel = %version-%release

%description -n %{libclient}-devel
Development libraries from silc-client

%package -n %{libname}-devel
Summary: Development libraries from silc
Group: Development/Other
Provides: %libname-devel = %version-%release
Requires: %{libname} = %version-%release

%description -n %{libname}-devel
Development libraries from silc

%package -n silc-perl
Summary: Perl Irssi module from silc
Group: Development/Perl
Conflicts: irssi 

%description -n silc-perl
Perl Irssi module from silc

%define _silcdatadir %{_datadir}/silc
%define _silclibdir %{_libdir}/silc
%define _silcetcdir %{_sysconfdir}/silc

%prep
%setup -q
chmod 644 CHANGES COPYING CREDITS README TODO doc/FAQ
chmod 644 doc/example_silcd.conf doc/silcalgs.conf doc/*.txt
chmod 644 irssi/docs/*.txt irssi/docs/*.html

%build
%configure --cache-file=`pwd`/config.cache --with-etcdir=%{_silcetcdir} \
--with-helpdir=%{_silcdatadir}/help --with-logsdir=%{_var}/log/silc \
--mandir=%{_mandir} --with-simdir=%{_silclibdir}/modules \
--enable-ipv6 --disable-debug \
--with-silcd-pid-file=%{_var}/run/silcd.pid \
--enable-shared \
--with-perl=module \
--with-perl-lib=vendor

# Set the built-in default perl module dir
# We don't care even if it doesn't exist yet
CC=$RPM_OPT_FLAGS make 

%install
rm -rf "$RPM_BUILD_ROOT"
make install DESTDIR="$RPM_BUILD_ROOT" PREFIX="$RPM_BUILD_ROOT/usr" 

# makefile sucks with libs
for i in lib/{.libs/{*.so*,*.a},*.la}; do
	cp -d $i $RPM_BUILD_ROOT%{_silclibdir}
done

# This Makefile really sucks (tm)
(
cd irssi/src/perl
make install DESTDIR="$RPM_BUILD_ROOT" PREFIX="$RPM_BUILD_ROOT/usr"
)

#install conf file, makeinstall don't do it (it really sucks)
cp ./doc/silcalgs.conf $RPM_BUILD_ROOT/%{_silcetcdir}
cp ./irssi/silc.conf $RPM_BUILD_ROOT/%{_silcetcdir}


# delete unwant files since rpmbuild failed if unpackaged
rm -fr $RPM_BUILD_ROOT%{_prefix}/doc
rm -f $RPM_BUILD_ROOT%{_silcetcdir}/silcd.conf
rm -rf $RPM_BUILD_ROOT%_prefix/libsilc*

# create menu entry and install icons
install -d %buildroot%{_iconsdir}
( cd %buildroot%{_iconsdir} ;tar jxf  %{SOURCE1} )

mkdir -p $RPM_BUILD_ROOT%{_menudir}
cat << EOF > $RPM_BUILD_ROOT%{_menudir}/silc-client
?package(silc-client):needs="text" section="Networking/Chat" \
title="Silc-client" command="silc" \
longtitle="Client for the secure Internet Live Conferencing (SILC) protocol" \
description="SILC client" \
icon="silc.png"
EOF

%post
%{update_menus}

%postun
%{update_menus}

%post -n %{libclient} -p /sbin/ldconfig

%postun -n %{libclient} -p /sbin/ldconfig

%post -n %{libname}
grep -q "^%_silclibdir$" /etc/ld.so.conf || echo "%_silclibdir" >> /etc/ld.so.conf
/sbin/ldconfig

%postun -n %{libname}
if [ "$1" = "0" ]; then
   rm -f /etc/ld.so.conf.new
   grep -v -e "%_silclibdir" /etc/ld.so.conf > /etc/ld.so.conf.new
   mv -f /etc/ld.so.conf.new /etc/ld.so.conf
fi
/sbin/ldconfig

%clean
rm -rf "$RPM_BUILD_ROOT"

%files
%defattr(-,root,root)
%doc CHANGES COPYING CREDITS README TODO doc/FAQ
%doc irssi/docs/*.txt
%doc irssi/docs/startup-HOWTO.html

%{_mandir}/man1/*

%{_iconsdir}/*.png
%{_iconsdir}/mini/*.png
%{_iconsdir}/large/*.png
%{_menudir}/%{name}

%{_bindir}/silc

%dir %{_silcdatadir}
%{_silcdatadir}/help
%{_silcdatadir}/scripts

%dir %{_silcdatadir}/themes
%{_silcdatadir}/themes/default.theme

%dir %{_silclibdir}
#%{_silclibdir}/perl5/*
%{_silclibdir}/modules/*.so

%dir %{_silcetcdir}
%config(noreplace) %{_silcetcdir}/silc.conf
%config(noreplace) %{_silcetcdir}/silcalgs.conf

%files -n silc-perl
%defattr(-,root,root)
%_libdir/perl5/*

%files -n %{libclient}
%defattr(-,root,root)
%{_silclibdir}/libsilcclient*.so.*

%files -n %{libname}
%defattr(-,root,root)
%{_silclibdir}/libsilc*.so.*

%files -n %{libclient}-devel
%defattr(-,root,root)
%{_silclibdir}/libsilcclient*.so
%{_silclibdir}/libsilcclient.la
%{_silclibdir}/libsilcclient.a
%dir %{_silclibdir}/modules
%{_silclibdir}/modules/*.la
%{_silclibdir}/modules/*.a

%files -n %{libname}-devel
%defattr(-,root,root)
%{_silclibdir}/libsilc*.so
%{_silclibdir}/libsilc.a
%{_silclibdir}/libsilc.la

%changelog
* Wed Jan 14 2004 Tibor Pittich <Tibor.Pittich@mandrake.org> 1.0.1-2mdk
- fixed glib BuildRequires

* Wed Jan 14 2004 Tibor Pittich <Tibor.Pittich@mandrake.org> 1.0.1-1mdk
- new bugfix release
- removed libtool hara-kiri

* Fri Nov 28 2003 Tibor Pittich <Tibor.Pittich@phuture.sk> 1.0-1mdk
- yes, yes; this is finally version 1.0 :)
- there is temporary fix for libtool problem, thanks to c0ffee

* Tue Nov 18 2003 Tibor Pittich <Tibor.Pittich@phuture.sk> 0.9.16-1mdk
- new bugfix release
- update Source link

* Fri Oct 31 2003 Tibor Pittich <Tibor.Pittich@phuture.sk> 0.9.15-1mdk
- new version

* Sun Oct 26 2003 Tibor Pittich <Tibor.Pittich@phuture.sk> 0.9.14-1mdk
- new version

* Thu Oct 16 2003 Tibor Pittich <Tibor.Pittich@phuture.sk> 0.9.13-1mdk
- new version
- removed mandir patch

* Wed Sep 24 2003 Lenny Cartier <lenny@mandrakesoft.com> 0.9.12.1-1mdk
- 0.9.12.1
- Patch1 is now Patch0
- regenerate Patch1 which is Patch0 (you listening ?)

* Sun Apr 27 2003 Tibor Pittich <Tibor.Pittich@phuture.sk> 0.9.12-3mdk
- add missing dir into files section (mr. distlint)

* Sat Apr 26 2003 Tibor Pittich <Tibor.Pittich@phuture.sk> 0.9.12-2mdk
- fixed Requires and Builrequires section (thnx. to Stefan's robot)
- cleanup spec file (remove old non-mdk-contrib records)
- fixed permissions of source files
- add mklibname macro into definition of libname and libclient

* Tue Mar 18 2003 Tibor Pittich <Tibor.Pittich@phuture.sk> 0.9.12-1mdk
- 0.9.12 - bugfix release
	- Fixed RESOLVING flag handling in JOIN notify
	- Fixed incorrect connection deletion
- mandir patch synced with cvs

* Fri Jan 10 2003 Lenny Cartier <lenny@mandrakesoft.com> 0.9.11-1mdk
- 0.9.11

* Mon Dec 30 2002 Olivier Thauvin <thauvin@aerov.jussieu.fr> 0.9.10.1-1mdk
- 0.9.10.1
- fix install of lib and perl module
- By Tibor Pittich <Tibor.Pittich@phuture.sk>
	- SILC protocol version 1.2
		- add mandir dirty patch (thanks to johnny)
		- provide this hot package, because silc protocol changed, and it is
		  incompatibille with old silc-client ..

* Sun Nov 17 2002 Olivier Thauvin <thauvin@aerov.jussieu.fr> 0.9.8-3mdk
- add _silclibdir in ld.so.conf
- libsilcclient requires libsilc
- split perl module into silc-perl
- silc-perl conflicts with irssi
- remove _silclibdir/perl5 (seems to be unused)

* Wed Nov 13 2002 Olivier Thauvin <thauvin@aerov.jussieu.fr> 0.9.8-2mdk
- Add missing lib
- split into libsilc, libsilc-client

* Sun Nov 10 2002 Olivier Thauvin <thauvin@aerov.jussieu.fr> 0.9.8-1mdk
- By Tibor Pittich <Tibor.Pittich@phuture.sk>
	- new version
		- a lots of fixes and some new stuff
		- added manual page silc(1)
		- topics are now UTF-8
		- support for encrypted private key files is added
		- included latest fixes from irssi.org CVS
	- man page added into spec, define mandir
	- some changes dedicated to rpmlint (unmark default.theme as config,
	  update my .rpmmacros file)

* Tue Oct 22 2002 Olivier Thauvin <thauvin@aerov.jussieu.fr> 0.9.7-1mdk
- Excellent spec By Tibor Pittich <Tibor.Pittich@phuture.sk>
	- new version
		- totally new Irssi base from the irssi.org CVS
		- stabilisation
		- fixes several bugs with the new ATTR command
	- add silc-client into Mandrake menu system
	- add png icons

* Mon Oct 21 2002 Olivier Thauvin <thauvin@aerov.jussieu.fr> 0.9.6-1mdk 
- By Tibor Pittich <Tibor.Pittich@phuture.sk>
	- new version
	- remove previous patches

* Tue Sep 17 2002 Olivier Thauvin <thauvin@aerov.jussieu.fr> 0.9.5-1mdk 
- By Tibor Pittich <Tibor.Pittich@phuture.sk>
	- Added some user-friendly aliases
	- Removed some unsafe code from the original client
	- Also fixed temporarily the /detach bug [#24]
	- new version 0.9.5
	- Added a temporary fix for the "(null)" hostname bug

* Sat Jul 06 2002 Olivier Thauvin <thauvin@aerov.jussieu.fr> 0.9.4-2mdk
- Fix summary (Tibor Pittich <Tibor.Pittich@phuture.sk>)

* Fri Jul 05 2002 Olivier Thauvin <thauvin@aerov.jussieu.fr> 0.9.4-1mdk 
- From Tibor Pittich <Tibor.Pittich@phuture.sk>
	- First mdk package
- fix non %config

